@@ -53,6 +53,7 @@ fn choose_kernel(kernels: &[Kernel]) -> Result<Kernel> {
     if kernels.is_empty() {
         bail!(fl!("empty_list"));
     }
+
     // build dialoguer Select for kernel selection
     let n = Select::with_theme(&ColorfulTheme::default())
         .items(kernels)
@@ -67,10 +68,16 @@ fn update(installed_kernels: &[Kernel], kernels: &[Kernel]) -> Result<()> {
     for k in installed_kernels.iter() {
         k.remove()?;
     }
+
     for k in kernels.iter() {
         k.install_and_make_config(true)?;
     }
 
+    // Set the newest kernel as default entry
+    if let Some(k) = kernels.first() {
+        k.set_default()?;
+    }
+
     Ok(())
 }
 
@@ -89,9 +96,11 @@ fn init(config: &Config, installed_kernels: &[Kernel], kernels: &[Kernel]) -> Re
         )
         .stderr(Stdio::null())
         .spawn()?;
+
     // create folder structure
     println_with_prefix_and_fl!("create_folder");
     fs::create_dir_all(config.esp_mountpoint.join(REL_DEST_PATH))?;
+
     // Update systemd-boot kernels and entries
     update(installed_kernels, kernels)
 }
@@ -117,27 +126,39 @@ fn read_config() -> Result<Config> {
         },
         |f| {
             let mut config: Config = toml::from_slice(&f)?;
+
             // Migrate from old configuration
             let old_conf = "{VERSION}-{LOCALVERSION}";
             let new_conf = "{VERSION}";
+
             if config.vmlinuz.contains(old_conf) || config.initrd.contains(old_conf) {
                 println_with_prefix_and_fl!("conf_old");
                 config.vmlinuz = config.vmlinuz.replace(old_conf, new_conf);
                 config.initrd = config.initrd.replace(old_conf, new_conf);
                 fs::write(CONF_PATH, toml::to_string_pretty(&config)?)?;
             }
+
             Ok(config)
         },
     )
 }
 
+#[inline]
+fn install(kernel: &Kernel, force: bool) -> Result<()> {
+    kernel.install_and_make_config(force)?;
+    kernel.ask_set_default()?;
+    Ok(())
+}
+
 fn main() -> Result<()> {
     // CLI
     let matches: Opts = Opts::parse();
+
     // Read config, create a default one if the file is missing
     let config = read_config()?;
     let installed_kernels = Kernel::list_installed(&config)?;
     let kernels = Kernel::list(&config)?;
+
     // Switch table
     match matches.subcommands {
         Some(s) => match s {
@@ -160,7 +181,7 @@ fn main() -> Result<()> {
                         .ok_or_else(|| anyhow!(fl!("no_kernel")))?
                         .clone(),
                 };
-                kernel.install_and_make_config(args.force)?;
+                install(&kernel, args.force)?
             }
             SubCommands::ListInstalled(_) => {
                 for (i, k) in installed_kernels.iter().enumerate() {
@@ -180,7 +201,7 @@ fn main() -> Result<()> {
             }
             SubCommands::Update(_) => update(&installed_kernels, &kernels)?,
         },
-        None => choose_kernel(&kernels)?.install_and_make_config(false)?,
+        None => install(&choose_kernel(&kernels)?, true)?,
     }
 
     Ok(())
